#!/usr/bin/env python

import kr8s
from kr8s.objects import Node
from time import sleep
from typer import Typer

app = Typer()

@app.command()
def soft_drain(node_name: str):
    """Soft drain deployments from a node.

    Drain a node by first scaling each Deployment to n+1 replicas before
    removing the Pod on the node."""
    node = Node(node_name)
    node.cordon()
    for deploy in kr8s.get("deploy", namespace=kr8s.ALL):
        pods = deploy.pods()
        no_spare = all([pod.spec.nodeName == node_name for pod in pods])
        if not pods or not no_spare:
            continue

        answers = ["y", "n", "c"]
        while (answer := input(f"Soft move {deploy.namespace} / {deploy.name}? [{'/'.join(answers)}]")) not in answers: pass
        if answer == "y":
            for pod in pods:
                pod.annotate({"controller.kubernetes.io/pod-deletion-cost": "-99999"})
            initial_size = deploy.replicas
            deploy.scale(initial_size + 1)
            sleep(1)
            deploy.wait("condition=Available")
            for pod in deploy.pods():
                pod.wait("condition=Ready")
            deploy.scale(initial_size)
        elif answer == "c":
            return
